@@ -1,5 +1,5 @@
 /*
- * $Id: internet_addressing.c 8686 2010-07-19 20:56:54Z dothebart $
+ * $Id$
  *
  * This file contains functions which handle the mapping of Internet addresses
  * to users on the Citadel system.
@@ -779,8 +779,7 @@ struct CtdlMessage *convert_internet_message_buf(StrBuf **rfc822)
 		       (done == 0) ) 
 		{
 
-			if ((*pos=='\n') &&
-			    (!isspace(*(pos+1)))) 
+			if ( (*pos=='\n') && ((*(pos+1))!=0x20) && ((*(pos+1))!=0x09) )
 			{
 				end = pos;
 			}
