@@ -1,5 +1,5 @@
 /* 
- * $Id: serv_calendar.c 8550 2010-05-03 16:41:45Z ajc $ 
+ * $Id$ 
  *
  * This module implements iCalendar object processing and the Calendar>
  * room on a Citadel server.  It handles iCalendar objects using the
@@ -1907,7 +1907,7 @@ void cmd_ical(char *argbuf)
 void ical_CtdlCreateRoom(void)
 {
 	struct ctdlroom qr;
-	struct visit vbuf;
+	visit vbuf;
 
 	/* Create the calendar room if it doesn't already exist */
 	CtdlCreateRoom(USERCALENDARROOM, 4, "", 0, 1, 0, VIEW_CALENDAR);
@@ -2599,5 +2599,5 @@ CTDL_MODULE_INIT(calendar)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_calendar.c 8550 2010-05-03 16:41:45Z ajc $";
+	return "$Id$";
 }
