@@ -1,5 +1,5 @@
 /*
- * $Id: serv_pop3.c 8686 2010-07-19 20:56:54Z dothebart $ 
+ * $Id$ 
  *
  * POP3 service for the Citadel system
  *
@@ -185,7 +185,7 @@ void pop3_add_message(long msgnum, void *userdata) {
  * of messages in the inbox, or -1 for error)
  */
 int pop3_grab_mailbox(void) {
-        struct visit vbuf;
+        visit vbuf;
 	int i;
 
 	if (CtdlGetRoom(&CC->room, MAILROOM) != 0) return(-1);
@@ -472,7 +472,7 @@ void pop3_dele(char *argbuf) {
  */
 void pop3_update(void) {
 	int i;
-        struct visit vbuf;
+        visit vbuf;
 
 	long *deletemsgs = NULL;
 	int num_deletemsgs = 0;
@@ -745,5 +745,5 @@ CTDL_MODULE_INIT(pop3)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_pop3.c 8686 2010-07-19 20:56:54Z dothebart $";
+	return "$Id$";
 }
