@@ -1,5 +1,5 @@
 /*
- * $Id: serv_vcard.c 8633 2010-06-20 21:44:24Z dothebart $
+ * $Id$
  * 
  * A server-side module for Citadel which supports address book information
  * using the standard vCard format.
@@ -1171,7 +1171,7 @@ void check_get_greeting(void) {
 void vcard_CtdlCreateRoom(void)
 {
 	struct ctdlroom qr;
-	struct visit vbuf;
+	visit vbuf;
 
 	/* Create the calendar room if it doesn't already exist */
 	CtdlCreateRoom(USERCONTACTSROOM, 4, "", 0, 1, 0, VIEW_ADDRESSBOOK);
@@ -1473,5 +1473,5 @@ CTDL_MODULE_INIT(vcard)
 	}
 	
 	/* return our Subversion id for the Log */
-	return "$Id: serv_vcard.c 8633 2010-06-20 21:44:24Z dothebart $";
+	return "$Id$";
 }
